/*****************************************************************************
 * Open MCT, Copyright (c) 2014-2024, United States Government
 * as represented by the Administrator of the National Aeronautics and Space
 * Administration. All rights reserved.
 *
 * Open MCT is licensed under the Apache License, Version 2.0 (the
 * 'License'); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an 'AS IS' BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 * Open MCT includes source code licensed under additional open source
 * licenses. See the Open Source Licenses file (LICENSES.md) included with
 * this source code distribution or the Licensing information page available
 * at runtime from the About dialog for additional information.
 *****************************************************************************/
import { createOpenMct, resetApplicationState } from 'utils/testing';

const OLD_ROOT_NAME = 'Open MCT';
const NEW_ROOT_NAME = 'not_a_root';

let openmct;

describe('the DefaultRootNamePlugin', () => {
  describe('without DefaultRootNamePlugin', () => {
    beforeEach((done) => {
      openmct = createOpenMct();

      openmct.on('start', done);
      openmct.startHeadless();
    });

    afterEach(() => {
      return resetApplicationState(openmct);
    });

    it('does not changes root name', (done) => {
      openmct.objects.getRoot().then((object) => {
        expect(object.name).toEqual(OLD_ROOT_NAME);

        done();
      });
    });
  });

  describe('with DefaultRootNamePlugin', () => {
    beforeEach((done) => {
      openmct = createOpenMct();

      openmct.install(openmct.plugins.DefaultRootName(NEW_ROOT_NAME));
      openmct.on('start', done);
      openmct.startHeadless();
    });

    afterEach(() => {
      return resetApplicationState(openmct);
    });

    it('changes root name', (done) => {
      openmct.objects.getRoot().then((object) => {
        expect(object.name).toEqual(NEW_ROOT_NAME);

        done();
      });
    });
  });
});
